Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Graph ¶
type Graph struct {
// contains filtered or unexported fields
}
Nodes and edges for a graph. This also has some internal data structures to facilitate walking the expression tree(s) of rules.
func BuildRuleDiagram ¶
Build a diagram of the interdependency of all rule files passed in. We expect that these have already been checked for errors and passed that check.
When we have processed these, simply serialise the graph as a DOT graph to w.
Click to show internal directories.
Click to hide internal directories.